scingestor package
==================

Submodules
----------

scingestor.beamtimeWatcher module
---------------------------------

.. automodule:: scingestor.beamtimeWatcher
   :members:
   :undoc-members:
   :show-inheritance:

scingestor.configuration module
-------------------------------

.. automodule:: scingestor.configuration
   :members:
   :undoc-members:
   :show-inheritance:

scingestor.datasetIngest module
-------------------------------

.. automodule:: scingestor.datasetIngest
   :members:
   :undoc-members:
   :show-inheritance:

scingestor.datasetIngestor module
---------------------------------

.. automodule:: scingestor.datasetIngestor
   :members:
   :undoc-members:
   :show-inheritance:

scingestor.datasetWatcher module
--------------------------------

.. automodule:: scingestor.datasetWatcher
   :members:
   :undoc-members:
   :show-inheritance:

scingestor.logger module
------------------------

.. automodule:: scingestor.logger
   :members:
   :undoc-members:
   :show-inheritance:

scingestor.modelIngest module
-----------------------------

.. automodule:: scingestor.modelIngest
   :members:
   :undoc-members:
   :show-inheritance:

scingestor.pathConverter module
-------------------------------

.. automodule:: scingestor.pathConverter
   :members:
   :undoc-members:
   :show-inheritance:

scingestor.safeINotifier module
-------------------------------

.. automodule:: scingestor.safeINotifier
   :members:
   :undoc-members:
   :show-inheritance:

scingestor.scanDirWatcher module
--------------------------------

.. automodule:: scingestor.scanDirWatcher
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: scingestor
   :members:
   :undoc-members:
   :show-inheritance:
